pub enum AssetReportType {
Full,
Fast,
}Expand description
Indicates either a Fast Asset Report, which will contain only current identity and balance information, or a Full Asset Report, which will also contain historical balance information and transaction data.
Variants