pub enum ExpirationDate {
NotExpired,
Expired,
NoData,
}Expand description
A description of whether the associated document was expired when the verification was performed.
Note: In the case where an expiration date is not present on the document or failed to be extracted, this value will be no_data.
Variants