pub enum SweepTrigger {
Manual,
Incoming,
BalanceThreshold,
AutomaticAggregate,
}Expand description
The trigger of the sweep
"manual" - The sweep is created manually by the customer
"incoming" - The sweep is created by incoming funds flow (e.g. Incoming Wire)
"balance_threshold" - The sweep is created by balance threshold setting
"automatic_aggregate" - The sweep is created by the Plaid automatic aggregation process. These funds did not pass through the Plaid Ledger balance.
Variants