pub struct AccountVerificationInsights {
pub account_number_format: AccountVerificationInsightsAccountNumberFormat,
pub network_status: AccountVerificationInsightsNetworkStatus,
pub previous_returns: Option<AccountVerificationInsightsPreviousReturns>,
}Expand description
Insights from performing database verification for the account. Only returned for Auth Items created via Database Insights.
Fields
account_number_format: AccountVerificationInsightsAccountNumberFormatIndicator of account number format validity for institution.
valid: indicates that the account number has a correct format for the institution.
invalid: indicates that the account number has an incorrect format for the institution.
unknown: indicates that there was not enough information to determine whether the format is correct for the institution.
network_status: AccountVerificationInsightsNetworkStatusStatus information about the account and routing number in the Plaid network.
previous_returns: Option<AccountVerificationInsightsPreviousReturns>Information about known ACH returns for the account and routing number.