pub struct AssetReportFilterResponse {
pub asset_report_id: String,
pub asset_report_token: String,
pub request_id: String,
}Expand description
AssetReportFilterResponse defines the response schema for /asset_report/filter
Fields
asset_report_id: StringA unique ID identifying an Asset Report. Like all Plaid identifiers, this ID is case sensitive.
asset_report_token: StringA token that can be provided to endpoints such as /asset_report/get or /asset_report/pdf/get to fetch or update an Asset Report.
request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.