pub struct AssetReportItem {
pub accounts: Vec<AccountAssets>,
pub date_last_updated: DateTime<Utc>,
pub institution_id: String,
pub institution_name: String,
pub item_id: String,
}Expand description
A representation of an Item within an Asset Report.
Fields
accounts: Vec<AccountAssets>Data about each of the accounts open on the Item.
date_last_updated: DateTime<Utc>The date and time when this Item’s data was last retrieved from the financial institution, in ISO 8601 format.
institution_id: StringThe id of the financial institution associated with the Item.
institution_name: StringThe full financial institution name associated with the Item.
item_id: StringThe item_id of the Item associated with this webhook, warning, or error