pub struct BeaconUserIdNumber {
pub type_: IdNumberType,
pub value: String,
}Expand description
The ID number associated with a Beacon User.
Fields
type_: IdNumberTypeA globally unique and human readable ID type, specific to the country and document category. For more context on this field, see Hybrid Input Validation.
value: StringValue of identity document value typed in by user. Alpha-numeric, with all formatting characters stripped. For specific format requirements by ID type, see Hybrid Input Validation.