pub struct CraIncomeInsights {
pub bank_income_summary: Option<CraBankIncomeSummary>,
pub days_requested: Option<i64>,
pub generated_time: Option<DateTime<Utc>>,
pub items: Option<Vec<CraBankIncomeItem>>,
pub report_id: Option<String>,
pub warnings: Option<Vec<CraBankIncomeWarning>>,
}Expand description
The Check Income Insights Report for an end user.
Fields
bank_income_summary: Option<CraBankIncomeSummary>Summary for income across all income sources and items (max history of 730 days).
days_requested: Option<i64>The number of days requested by the customer for the Check Income Insights Report.
generated_time: Option<DateTime<Utc>>The time when the Check Income Insights Report was generated.
items: Option<Vec<CraBankIncomeItem>>The list of Items in the report along with the associated metadata about the Item.
report_id: Option<String>The unique identifier associated with the Check Income Insights Report.
warnings: Option<Vec<CraBankIncomeWarning>>If data from the report was unable to be retrieved, the warnings object will contain information about the error that caused the data to be incomplete.