pub struct CraLoanRegisterApplication {
pub application_date: Option<NaiveDate>,
pub application_id: Option<String>,
}Expand description
Contains loan application data to register.
Fields
application_date: Option<NaiveDate>The date the user applied for the loan. The date should be in ISO 8601 format (YYYY-MM-DD).
application_id: Option<String>A unique identifier for the loan application.
Personally identifiable information, such as an email address or phone number, should not be used in the application_id.