pub struct CreditBankIncomeAccount {
pub account_id: String,
pub mask: Option<String>,
pub name: String,
pub official_name: Option<String>,
pub owners: Vec<Owner>,
pub subtype: DepositoryAccountSubtype,
pub type_: CreditBankIncomeAccountType,
}Expand description
The Item’s bank accounts that have the selected data.
Fields
account_id: StringPlaid’s unique identifier for the account.
mask: Option<String>The last 2-4 alphanumeric characters of an account’s official account number. Note that the mask may be non-unique between an Item’s accounts, and it may also not match the mask that the bank displays to the user.
name: StringThe name of the bank account.
official_name: Option<String>The official name of the bank account.
owners: Vec<Owner>Data returned by the financial institution about the account owner or owners. Identity information is optional, so field may return an empty array.
subtype: DepositoryAccountSubtypeValid account subtypes for depository accounts. For a list containing descriptions of each subtype, see Account schemas.
type_: CreditBankIncomeAccountTypeThe account type. This will always be depository.