pub struct CreditBankStatementUploadBankAccount {
pub account_id: Option<String>,
pub account_number: Option<String>,
pub account_type: Option<String>,
pub bank_name: Option<String>,
pub name: Option<String>,
pub owner: CreditBankStatementUploadAccountOwner,
pub periods: Vec<CreditBankStatementUploadBankAccountPeriod>,
}Expand description
An object containing data about a user’s bank account related to an uploaded bank statement.
Fields
account_id: Option<String>The unique id of the bank account
account_number: Option<String>The bank account number.
account_type: Option<String>The type of the bank account.
bank_name: Option<String>The name of the bank institution.
name: Option<String>The name of the bank account
owner: CreditBankStatementUploadAccountOwnerAn object containing data about the owner of the bank account for the uploaded bank statement.
periods: Vec<CreditBankStatementUploadBankAccountPeriod>An array of period objects, containing more data on the overall period of the statement.