pub struct CreditRelayRefreshResponse {
pub asset_report_id: Option<String>,
pub relay_token: String,
pub request_id: String,
}Expand description
CreditRelayRefreshResponse defines the response schema for /credit/relay/refresh
Fields
asset_report_id: Option<String>A unique ID identifying an Asset Report. Like all Plaid identifiers, this ID is case sensitive.
relay_token: Stringrequest_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.