pub struct CreditSessionsGetResponse {
pub request_id: String,
pub sessions: Option<Vec<CreditSession>>,
}Expand description
CreditSessionsGetResponse defines the response schema for /credit/sessions/get
Fields
request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
sessions: Option<Vec<CreditSession>>A list of Link sessions for the user. Sessions will be sorted in reverse chronological order.