pub struct DetectedAccount {
pub account_subtype: Option<String>,
pub account_type: Option<String>,
pub newest_transaction_amount: Option<f64>,
pub newest_transaction_date: Option<NaiveDate>,
pub oldest_transaction_date: Option<NaiveDate>,
pub total_inflows: f64,
pub total_outflows: f64,
pub transaction_count: i64,
}Expand description
A possible account detected to be associated with a transaction user.
Fields
account_subtype: Option<String>The detected subtype of the account, based on the transactions to/from the institution.
account_type: Option<String>The detected account type (depository, credit, loan, investment etc.).
newest_transaction_amount: Option<f64>Amount of the most recent transaction associated with this detected account type at this financial institution.
newest_transaction_date: Option<NaiveDate>The date of the newest transaction associated with this detected account type at this financial institution.
oldest_transaction_date: Option<NaiveDate>The date of the oldest transaction associated with this detected account type at this financial institution.
total_inflows: f64Sum of inflow amounts associated with this detected account type at this financial institution.
total_outflows: f64Sum of outflow amounts associated with this detected account type at this financial institution.
transaction_count: i64The number of transactions associated with this detected account type at this financial institution.