pub struct DocumentRiskSignal {
pub actual_value: Option<String>,
pub expected_value: Option<String>,
pub field: Option<String>,
pub has_fraud_risk: Option<bool>,
pub institution_metadata: Option<DocumentRiskSignalInstitutionMetadata>,
pub page_number: Option<i64>,
pub signal_description: Option<String>,
pub type_: Option<String>,
}Expand description
Details about a certain reason as to why a document could potentially be fraudulent.
Fields
actual_value: Option<String>The derived value obtained in the risk signal calculation process for this field
expected_value: Option<String>The expected value of the field, as seen on the document
field: Option<String>The field which the risk signal was computed for
has_fraud_risk: Option<bool>A flag used to quickly identify if the signal indicates that this field is authentic or fraudulent
institution_metadata: Option<DocumentRiskSignalInstitutionMetadata>An object which contains additional metadata about the institution used to compute the verification attribute
page_number: Option<i64>The relevant page associated with the risk signal. If the risk signal is not associated with a specific page, the value will be 0.
signal_description: Option<String>A human-readable explanation providing more detail into the particular risk signal
type_: Option<String>The type of risk found in the risk signal check.