pub struct EmploymentDetails {
pub annual_salary: Option<Pay>,
pub hire_date: Option<NaiveDate>,
}Expand description
An object representing employment details found on a paystub.
Fields
annual_salary: Option<Pay>An object representing a monetary amount.
hire_date: Option<NaiveDate>Date on which the employee was hired, in the YYYY-MM-DD format.