pub struct EntityScreeningHitNames {
pub full: String,
pub is_primary: bool,
pub weak_alias_determination: WeakAliasDetermination,
}Expand description
Name information for the associated entity watchlist hit
Fields
full: StringThe full name of the entity.
is_primary: boolPrimary names are those most commonly used to refer to this entity. Only one name will ever be marked as primary.
weak_alias_determination: WeakAliasDeterminationNames that are explicitly marked as low quality either by their source list, or by plaid by a series of additional checks done by Plaid. Plaid does not ever surface a hit as a result of a weak name alone. If a name has no quality issues, this value will be none.