pub struct FallbackAuthMicrodepositVerificationExpiredWebhook {
pub account_id: String,
pub environment: WebhookEnvironmentValues,
pub error: Option<String>,
pub item_id: String,
pub webhook_code: String,
pub webhook_type: String,
}Expand description
Fires when an account has an expired verification when using micro-deposits
Fields
account_id: StringThe external account ID associated with the micro-deposit
environment: WebhookEnvironmentValuesThe Plaid environment the webhook was sent from
error: Option<String>The error code associated with the webhook.
item_id: StringThe item_id of the Item associated with this webhook, warning, or error
webhook_code: StringVERIFICATION_EXPIRED
webhook_type: StringAUTH