pub struct IncomeVerificationPaystubsGetResponse {
pub document_metadata: Option<Vec<DocumentMetadata>>,
pub error: Option<PlaidError>,
pub paystubs: Vec<Paystub>,
pub request_id: String,
}Expand description
IncomeVerificationPaystubsGetResponse defines the response schema for /income/verification/paystubs/get.
Fields
document_metadata: Option<Vec<DocumentMetadata>>Metadata for an income document.
error: Option<PlaidError>Errors are identified by error_code and categorized by error_type. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-null error object will only be part of an API response when calling /item/get to view Item status. Otherwise, error fields will be null if no error has occurred; if an error has occurred, an error code will be returned instead.
paystubs: Vec<Paystub>request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.