pub struct InstitutionStatusAlertWebhook {
pub environment: WebhookEnvironmentValues,
pub institution_id: String,
pub institution_overall_success_rate: f64,
pub webhook_code: String,
pub webhook_type: String,
}Expand description
Fired when institution status meets the conditions configured in the developer dashboard.
Fields
environment: WebhookEnvironmentValuesThe Plaid environment the webhook was sent from
institution_id: StringThe ID of the associated institution.
institution_overall_success_rate: f64The global success rate of the institution, calculated based on item add health.
webhook_code: StringINSTITUTION_STATUS_ALERT_TRIGGERED
webhook_type: StringDASHBOARD_CONFIGURED_ALERT