InstitutionsSearchRequestOptions

Struct InstitutionsSearchRequestOptions 

pub struct InstitutionsSearchRequestOptions {
    pub include_auth_metadata: Option<bool>,
    pub include_optional_metadata: Option<bool>,
    pub include_payment_initiation_metadata: Option<bool>,
    pub oauth: Option<bool>,
    pub payment_initiation: Option<InstitutionsSearchPaymentInitiationOptions>,
}
An optional object to filter /institutions/search results.

Fields

include_auth_metadata: Option<bool>

When true, returns metadata related to the Auth product indicating which auth methods are supported.

include_optional_metadata: Option<bool>

When true, return the institution’s homepage URL, logo and primary brand color.

include_payment_initiation_metadata: Option<bool>

When true, returns metadata related to the Payment Initiation product indicating which payment configurations are supported.

oauth: Option<bool>

Limit results to institutions with or without OAuth login flows. Note that institutions will have oauth set to true if some Items associated with that institution are required to use OAuth flows; institutions in a state of migration to OAuth will have the oauth attribute set to true.

payment_initiation: Option<InstitutionsSearchPaymentInitiationOptions>

Additional options that will be used to filter institutions by various Payment Initiation configurations.