LinkTokenCreateRequestBaseReport

Struct LinkTokenCreateRequestBaseReport 

pub struct LinkTokenCreateRequestBaseReport {
    pub client_report_id: Option<String>,
    pub days_requested: i64,
}
Specifies options for initializing Link for use with the Base Report product. This field is required if assets is included in the products array and the client is CRA-enabled.

Fields

client_report_id: Option<String>

Client-generated identifier, which can be used by lenders to track loan applications.

days_requested: i64

The maximum integer number of days of history to include in the Base Report.