pub struct Loan {
pub loan_identifiers: LoanIdentifiers,
}Expand description
Information specific to a mortgage loan agreement between one or more borrowers and a mortgage lender.
Fields
loan_identifiers: LoanIdentifiersCollection of current and previous identifiers for this loan.