pub struct PayStubDeductionsTotal {
pub current_amount: Option<f64>,
pub iso_currency_code: Option<String>,
pub unofficial_currency_code: Option<String>,
pub ytd_amount: Option<f64>,
}Expand description
An object representing the total deductions for the pay period
Fields
current_amount: Option<f64>Raw amount of the deduction
iso_currency_code: Option<String>The ISO-4217 currency code of the line item. Always null if unofficial_currency_code is non-null.
unofficial_currency_code: Option<String>The unofficial currency code associated with the line item. Always null if iso_currency_code is non-null. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.
See the currency code schema for a full listing of supported iso_currency_codes.
ytd_amount: Option<f64>The year-to-date total amount of the deductions