pub struct PaymentAmountNullable {
pub currency: PaymentAmountCurrency,
pub value: f64,
}Expand description
The amount and currency of a payment
Fields
currency: PaymentAmountCurrencyThe ISO-4217 currency code of the payment. For standing orders and payment consents, "GBP" must be used. For Poland, Denmark, Sweden and Norway, only the local currency is currently supported.
value: f64The amount of the payment. Must contain at most two digits of precision e.g. 1.23.