pub struct RoleDetail {
pub party_role_type: PartyRoleType,
}Expand description
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
Fields
party_role_type: PartyRoleTypeA value from a MISMO defined list that identifies the role that the party plays in the transaction. Parties may be either a person or legal entity. A party may play multiple roles in a transaction.A value from a MISMO defined list that identifies the role that the party plays in the transaction. Parties may be either a person or legal entity. A party may play multiple roles in a transaction.