pub struct SandboxTransferRefundSimulateResponse {
pub request_id: String,
}Expand description
Defines the response schema for /sandbox/transfer/refund/simulate
Fields
request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.