pub struct SelfieAnalysis {
pub document_comparison: SelfieAnalysisDocumentComparison,
pub facial_analysis: Option<SelfieAnalysisFacialAnalysis>,
pub liveness_check: SelfieAnalysisLivenessCheck,
}Expand description
High level descriptions of how the associated selfie was processed. If a selfie fails verification, the details in the analysis object should help clarify why the selfie was rejected.
Fields
document_comparison: SelfieAnalysisDocumentComparisonInformation about the comparison between the selfie and the document (if documentary verification also ran).
facial_analysis: Option<SelfieAnalysisFacialAnalysis>Analysis of the facial features of the selfie when compared to the face in the uploaded document, if one is present.
liveness_check: SelfieAnalysisLivenessCheckAssessment of whether the selfie capture is of a real human being, as opposed to a picture of a human on a screen, a picture of a paper cut out, someone wearing a mask, or a deepfake.