pub struct ServiceProductFulfillment {
pub service_product_fulfillment_detail: ServiceProductFulfillmentDetail,
}Expand description
A collection of details related to a fulfillment service or product in terms of request, process and result.
Fields
service_product_fulfillment_detail: ServiceProductFulfillmentDetailDocumentation not found in the MISMO model viewer and not provided by Freddie Mac.