pub struct TaxpayerIdentifiers {
pub taxpayer_identifier: TaxpayerIdentifier,
}Expand description
The collection of TAXPAYER_IDENTIFICATION elements
Fields
taxpayer_identifier: TaxpayerIdentifierInformation about the Taxpayer identification values assigned to the individual or legal entity.Information about the Taxpayer identification values assigned to the individual or legal entity.