pub struct TransferGetResponse {
pub request_id: String,
pub transfer: Transfer,
}Expand description
Defines the response schema for /transfer/get
Fields
request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
transfer: TransferRepresents a transfer within the Transfers API.