pub struct TransferPlatformPersonAddress {
pub city: String,
pub country: String,
pub postal_code: String,
pub region: String,
pub street: String,
pub street2: Option<String>,
}Expand description
Home address of a person
Fields
city: StringThe full city name.
country: StringValid, capitalized, two-letter ISO code representing the country of this object. Must be in ISO 3166-1 alpha-2 form.
postal_code: StringThe postal code of the address.
region: StringAn ISO 3166-2 subdivision code. Related terms would be “state”, “province”, “prefecture”, “zone”, “subdivision”, etc.
street: StringThe primary street portion of an address. A string with at least one non-whitespace alphabetical character, with a max length of 80 characters.
street2: Option<String>Extra street information, like an apartment or suite number. If provided, a string with at least one non-whitespace character, with a max length of 50 characters.