pub struct TransferRepaymentListResponse {
pub repayments: Vec<TransferRepayment>,
pub request_id: String,
}Expand description
Defines the response schema for /transfer/repayments/list
Fields
repayments: Vec<TransferRepayment>request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.