pub struct UserThirdPartyTokenRemoveResponse {
pub removed: bool,
pub request_id: String,
}Expand description
UserThirdPartyTokenCreateResponse defines the response schema for /user/third_party_token/remove
Fields
removed: booltrue if the third-party user token was successfully removed.
request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.