pub struct WalletListResponse {
pub next_cursor: Option<String>,
pub request_id: String,
pub wallets: Vec<Wallet>,
}Expand description
WalletListResponse defines the response schema for /wallet/list
Fields
next_cursor: Option<String>Cursor used for fetching e-wallets created before the latest e-wallet provided in this response
request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
wallets: Vec<Wallet>An array of e-wallets