pub struct WalletTransactionListResponse {
pub next_cursor: Option<String>,
pub request_id: String,
pub transactions: Vec<WalletTransaction>,
}Expand description
WalletTransactionListResponse defines the response schema for /wallet/transaction/list
Fields
next_cursor: Option<String>Cursor used for fetching transactions created before the latest transaction provided in this response
request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
transactions: Vec<WalletTransaction>An array of transactions of an e-wallet, associated with the given wallet_id