pub struct AccountAccess {
pub account_product_access: Option<AccountProductAccess>,
pub authorized: Option<bool>,
pub unique_id: String,
}Expand description
Allow or disallow product access by account. Unlisted (e.g. missing) accounts will be considered new_accounts.
Fields
account_product_access: Option<AccountProductAccess>Allow the application to access specific products on this account
Allow the application to see this account (and associated details, including balance) in the list of accounts If unset, defaults to true.
unique_id: StringThe unique account identifier for this account. This value must match that returned by the data access API for this account.