pub struct EntityScreeningHitAnalysis {
pub documents: Option<MatchSummaryCode>,
pub email_addresses: Option<MatchSummaryCode>,
pub locations: Option<MatchSummaryCode>,
pub names: Option<MatchSummaryCode>,
pub phone_numbers: Option<MatchSummaryCode>,
pub search_terms_version: i64,
pub urls: Option<MatchSummaryCode>,
}Expand description
Analysis information describing why a screening hit matched the provided entity information
Fields
documents: Option<MatchSummaryCode>An enum indicating the match type between data provided by user and data checked against an external data source.
match indicates that the provided input data was a strong match against external data.
partial_match indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name.
no_match indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data.
no_data indicates that Plaid was unable to find external data to compare against the provided input data.
no_input indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
email_addresses: Option<MatchSummaryCode>An enum indicating the match type between data provided by user and data checked against an external data source.
match indicates that the provided input data was a strong match against external data.
partial_match indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name.
no_match indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data.
no_data indicates that Plaid was unable to find external data to compare against the provided input data.
no_input indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
locations: Option<MatchSummaryCode>An enum indicating the match type between data provided by user and data checked against an external data source.
match indicates that the provided input data was a strong match against external data.
partial_match indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name.
no_match indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data.
no_data indicates that Plaid was unable to find external data to compare against the provided input data.
no_input indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
names: Option<MatchSummaryCode>An enum indicating the match type between data provided by user and data checked against an external data source.
match indicates that the provided input data was a strong match against external data.
partial_match indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name.
no_match indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data.
no_data indicates that Plaid was unable to find external data to compare against the provided input data.
no_input indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
phone_numbers: Option<MatchSummaryCode>An enum indicating the match type between data provided by user and data checked against an external data source.
match indicates that the provided input data was a strong match against external data.
partial_match indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name.
no_match indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data.
no_data indicates that Plaid was unable to find external data to compare against the provided input data.
no_input indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.
search_terms_version: i64The version of the entity screening’s search_terms that were compared when the entity screening hit was added. entity screening hits are immutable once they have been reviewed. If changes are detected due to updates to the entity screening’s search_terms, the associated entity program, or the list’s source data prior to review, the entity screening hit will be updated to reflect those changes.
urls: Option<MatchSummaryCode>An enum indicating the match type between data provided by user and data checked against an external data source.
match indicates that the provided input data was a strong match against external data.
partial_match indicates the data approximately matched against external data. For example, “Knope” vs. “Knope-Wyatt” for last name.
no_match indicates that Plaid was able to perform a check against an external data source and it did not match the provided input data.
no_data indicates that Plaid was unable to find external data to compare against the provided input data.
no_input indicates that Plaid was unable to perform a check because no information was provided for this field by the end user.