pub struct HoldingsDefaultUpdateWebhook {
pub environment: WebhookEnvironmentValues,
pub error: Option<PlaidError>,
pub item_id: String,
pub new_holdings: f64,
pub updated_holdings: f64,
pub webhook_code: String,
pub webhook_type: String,
}Expand description
Fired when new or updated holdings have been detected on an investment account. The webhook typically fires in response to any newly added holdings or price changes to existing holdings, most commonly after market close.
Fields
environment: WebhookEnvironmentValuesThe Plaid environment the webhook was sent from
error: Option<PlaidError>Errors are identified by error_code and categorized by error_type. Use these in preference to HTTP status codes to identify and handle specific errors. HTTP status codes are set and provide the broadest categorization of errors: 4xx codes are for developer- or user-related errors, and 5xx codes are for Plaid-related errors, and the status will be 2xx in non-error cases. An Item with a non-null error object will only be part of an API response when calling /item/get to view Item status. Otherwise, error fields will be null if no error has occurred; if an error has occurred, an error code will be returned instead.
item_id: StringThe item_id of the Item associated with this webhook, warning, or error
new_holdings: f64The number of new holdings reported since the last time this webhook was fired.
updated_holdings: f64The number of updated holdings reported since the last time this webhook was fired.
webhook_code: StringDEFAULT_UPDATE
webhook_type: StringHOLDINGS