pub struct RiskCheckIdentityAbuseSignals {
pub stolen_identity: Option<RiskCheckStolenIdentity>,
pub synthetic_identity: Option<RiskCheckSyntheticIdentity>,
}Expand description
Result summary object capturing abuse signals related to identity abuse, e.g. stolen and synthetic identity fraud. These attributes are only available for US identities and some signals may not be available depending on what information was collected.
Fields
stolen_identity: Option<RiskCheckStolenIdentity>Field containing the data used in determining the outcome of the stolen identity risk check.
Contains the following fields:
score - A score from 0 to 100 indicating the likelihood that the user is a stolen identity.
synthetic_identity: Option<RiskCheckSyntheticIdentity>Field containing the data used in determining the outcome of the synthetic identity risk check.
Contains the following fields:
score - A score from 0 to 100 indicating the likelihood that the user is a synthetic identity.