pub struct Wallet {
pub balance: WalletBalance,
pub numbers: WalletNumbers,
pub recipient_id: Option<String>,
pub status: WalletStatus,
pub wallet_id: String,
}Expand description
An object representing the e-wallet
Fields
balance: WalletBalanceAn object representing the e-wallet balance
numbers: WalletNumbersAn object representing the e-wallet account numbers
recipient_id: Option<String>The ID of the recipient that corresponds to the e-wallet account numbers
status: WalletStatusThe status of the wallet.
UNKNOWN: The wallet status is unknown.
ACTIVE: The wallet is active and ready to send money to and receive money from.
CLOSED: The wallet is closed. Any transactions made to or from this wallet will error.
wallet_id: StringA unique ID identifying the e-wallet